@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -50,7 +51,7 @@ ResId SaneResId( sal_uInt32 );
 
 // ---------------------------------------------------------------------
 
-GridWindow::GridWindow(double* pXValues, double* pYValues, int nValues, Window* pParent, BOOL bCutValues ) 
+GridWindow::GridWindow(double* pXValues, double* pYValues, int nValues, Window* pParent, sal_Bool bCutValues ) 
 :	ModalDialog( pParent, SaneResId( GRID_DIALOG ) ),
     m_aGridArea( 50, 15, 100, 100 ),
     m_pXValues( pXValues ),
@@ -66,7 +67,7 @@ GridWindow::GridWindow(double* pXValues, double* pYValues, int nValues, Window*
     m_aResetTypeBox( this, SaneResId( GRID_DIALOG_TYPE_BOX ) ),
     m_aResetButton( this, SaneResId( GRID_DIALOG_RESET_BTN ) )
 {
-    USHORT nPos = m_aResetTypeBox.InsertEntry( String( SaneResId( RESET_TYPE_LINEAR_ASCENDING ) ) );
+    sal_uInt16 nPos = m_aResetTypeBox.InsertEntry( String( SaneResId( RESET_TYPE_LINEAR_ASCENDING ) ) );
     m_aResetTypeBox.SetEntryData( nPos, (void *)RESET_TYPE_LINEAR_ASCENDING );
 
     nPos = m_aResetTypeBox.InsertEntry( String( SaneResId( RESET_TYPE_LINEAR_DESCENDING ) ) );
@@ -606,3 +607,5 @@ IMPL_LINK( GridWindow, ClickButtonHdl, Button*, pButton )
     }
     return 0;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
