@@ -49,8 +49,8 @@
 
 using namespace com::sun::star::packages::zip::ZipConstants;
 using namespace com::sun::star::packages::zip;
-using namespace com::sun::star::container;
 using namespace com::sun::star::packages;
+using namespace com::sun::star::container;
 using namespace com::sun::star::beans;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::uno;
@@ -60,7 +60,6 @@ using namespace std;
 using namespace ::com::sun::star;
 
 using rtl::OUString;
-
 namespace { struct lcl_CachedImplId : public rtl::Static< Sequence < sal_Int8 >, lcl_CachedImplId > {}; }
 
 ZipPackageFolder::ZipPackageFolder ( const Reference< XMultiServiceFactory >& xFactory,
@@ -98,7 +97,7 @@ sal_Bool ZipPackageFolder::LookForUnexpectedODF12Streams( const ::rtl::OUString&
 
     for ( ContentHash::const_iterator aCI = maContents.begin(), aEnd = maContents.end();
           !bHasUnexpected && aCI != aEnd; 
-          aCI++)
+          ++aCI)
     { 
         const OUString &rShortName = (*aCI).first;
         const ContentInfo &rInfo = *(*aCI).second;
@@ -156,7 +155,7 @@ void ZipPackageFolder::setChildStreamsTypeByExtension( const beans::StringPair&
 
     for ( ContentHash::const_iterator aCI = maContents.begin(), aEnd = maContents.end();
           aCI != aEnd; 
-          aCI++)
+          ++aCI)
     { 
         const OUString &rShortName = (*aCI).first;
         const ContentInfo &rInfo = *(*aCI).second;
@@ -272,11 +271,10 @@ Sequence< OUString > SAL_CALL ZipPackageFolder::getElementNames(  )
 {
     sal_uInt32 i=0, nSize = maContents.size();
     Sequence < OUString > aSequence ( nSize );
-    OUString *pNames = aSequence.getArray();
     for ( ContentHash::const_iterator aIterator = maContents.begin(), aEnd = maContents.end(); 
           aIterator != aEnd; 
           ++i, ++aIterator)
-        pNames[i] = (*aIterator).first;
+        aSequence[i] = (*aIterator).first;
     return aSequence;
 }
 sal_Bool SAL_CALL ZipPackageFolder::hasByName( const OUString& aName ) 
@@ -307,12 +305,10 @@ static void ImplSetStoredData( ZipEntry & rEntry, Reference < XInputStream> & rS
     rEntry.nCrc = aCRC32.getValue();
 }
 
-void ZipPackageFolder::saveContents(OUString &rPath, std::vector < Sequence < PropertyValue > > &rManList, ZipOutputStream & rZipOut, Sequence < sal_Int8 > &rEncryptionKey, rtlRandomPool &rRandomPool)
-    throw(RuntimeException)
+bool ZipPackageFolder::saveChild( const OUString &rShortName, const ContentInfo &rInfo, OUString &rPath, std::vector < Sequence < PropertyValue > > &rManList, ZipOutputStream & rZipOut, Sequence < sal_Int8 > &rEncryptionKey, rtlRandomPool &rRandomPool)
 {
-    sal_Bool bWritingFailed = sal_False;
-    ZipPackageFolder *pFolder = NULL;
-    ZipPackageStream *pStream = NULL;
+    bool bSuccess = true;
+
     const OUString sMediaTypeProperty ( RTL_CONSTASCII_USTRINGPARAM ( "MediaType" ) );
     const OUString sVersionProperty ( RTL_CONSTASCII_USTRINGPARAM ( "Version" ) );
     const OUString sFullPathProperty ( RTL_CONSTASCII_USTRINGPARAM ( "FullPath" ) );
@@ -322,7 +318,357 @@ void ZipPackageFolder::saveContents(OUString &rPath, std::vector < Sequence < Pr
     const OUString sSizeProperty ( RTL_CONSTASCII_USTRINGPARAM ( "Size" ) );
     const OUString sDigestProperty ( RTL_CONSTASCII_USTRINGPARAM ( "Digest" ) );
 
-    sal_Bool bHaveEncryptionKey = rEncryptionKey.getLength() ? sal_True : sal_False;
+    Sequence < PropertyValue > aPropSet (PKG_SIZE_NOENCR_MNFST);
+
+    OSL_ENSURE( ( rInfo.bFolder && rInfo.pFolder ) || ( !rInfo.bFolder && rInfo.pStream ), "A valid child object is expected!" );
+    if ( rInfo.bFolder )
+    {
+        OUString sTempName = rPath + rShortName + OUString( RTL_CONSTASCII_USTRINGPARAM ( "/" ) );
+
+        if ( rInfo.pFolder->GetMediaType().getLength() )
+        {
+            aPropSet[PKG_MNFST_MEDIATYPE].Name = sMediaTypeProperty;
+            aPropSet[PKG_MNFST_MEDIATYPE].Value <<= rInfo.pFolder->GetMediaType();
+            aPropSet[PKG_MNFST_VERSION].Name = sVersionProperty;
+            aPropSet[PKG_MNFST_VERSION].Value <<= rInfo.pFolder->GetVersion();
+            aPropSet[PKG_MNFST_FULLPATH].Name = sFullPathProperty;
+            aPropSet[PKG_MNFST_FULLPATH].Value <<= sTempName;
+        }
+        else
+            aPropSet.realloc( 0 );
+
+        rInfo.pFolder->saveContents( sTempName, rManList, rZipOut, rEncryptionKey, rRandomPool);
+    }
+    else
+    {
+        // if pTempEntry is necessary, it will be released and passed to the ZipOutputStream
+        // and be deleted in the ZipOutputStream destructor
+        auto_ptr < ZipEntry > pAutoTempEntry ( new ZipEntry );
+        ZipEntry* pTempEntry = pAutoTempEntry.get();
+
+        // In case the entry we are reading is also the entry we are writing, we will
+        // store the ZipEntry data in pTempEntry
+
+        ZipPackageFolder::copyZipEntry ( *pTempEntry, rInfo.pStream->aEntry );
+        pTempEntry->sPath = rPath + rShortName;
+        pTempEntry->nPathLen = (sal_Int16)( ::rtl::OUStringToOString( pTempEntry->sPath, RTL_TEXTENCODING_UTF8 ).getLength() );
+
+        sal_Bool bToBeEncrypted = rInfo.pStream->IsToBeEncrypted() && (rEncryptionKey.getLength() || rInfo.pStream->HasOwnKey());
+        sal_Bool bToBeCompressed = bToBeEncrypted ? sal_True : rInfo.pStream->IsToBeCompressed();
+
+        aPropSet[PKG_MNFST_MEDIATYPE].Name = sMediaTypeProperty;
+        aPropSet[PKG_MNFST_MEDIATYPE].Value <<= rInfo.pStream->GetMediaType( );
+        aPropSet[PKG_MNFST_VERSION].Name = sVersionProperty;
+        aPropSet[PKG_MNFST_VERSION].Value <<= ::rtl::OUString(); // no version is stored for streams currently
+        aPropSet[PKG_MNFST_FULLPATH].Name = sFullPathProperty;
+        aPropSet[PKG_MNFST_FULLPATH].Value <<= pTempEntry->sPath;
+
+
+        OSL_ENSURE( rInfo.pStream->GetStreamMode() != PACKAGE_STREAM_NOTSET, "Unacceptable ZipPackageStream mode!" );
+
+        sal_Bool bRawStream = sal_False;
+        if ( rInfo.pStream->GetStreamMode() == PACKAGE_STREAM_DETECT )
+            bRawStream = rInfo.pStream->ParsePackageRawStream();
+        else if ( rInfo.pStream->GetStreamMode() == PACKAGE_STREAM_RAW )
+            bRawStream = sal_True;
+
+        sal_Bool bTransportOwnEncrStreamAsRaw = sal_False;
+        // During the storing the original size of the stream can be changed
+        // TODO/LATER: get rid of this hack
+        sal_Int32 nOwnStreamOrigSize = bRawStream ? rInfo.pStream->GetMagicalHackSize() : rInfo.pStream->getSize();
+
+        sal_Bool bUseNonSeekableAccess = sal_False;
+        Reference < XInputStream > xStream;
+        if ( !rInfo.pStream->IsPackageMember() && !bRawStream && !bToBeEncrypted && bToBeCompressed )
+        {
+            // the stream is not a package member, not a raw stream,
+            // it should not be encrypted and it should be compressed,
+            // in this case nonseekable access can be used
+
+            xStream = rInfo.pStream->GetOwnStreamNoWrap();
+            Reference < XSeekable > xSeek ( xStream, UNO_QUERY );
+
+            bUseNonSeekableAccess = ( xStream.is() && !xSeek.is() );
+        }
+
+        if ( !bUseNonSeekableAccess )
+        {
+            xStream = rInfo.pStream->getRawData();
+
+            if ( !xStream.is() )
+            {
+                OSL_FAIL( "ZipPackageStream didn't have a stream associated with it, skipping!" );
+                bSuccess = false;
+                return bSuccess;
+            }
+
+            Reference < XSeekable > xSeek ( xStream, UNO_QUERY );
+            try
+            {
+                if ( xSeek.is() )
+                {
+                    // If the stream is a raw one, then we should be positioned
+                    // at the beginning of the actual data
+                    if ( !bToBeCompressed || bRawStream )
+                    {
+                        // The raw stream can neither be encrypted nor connected
+                        OSL_ENSURE( !bRawStream || !(bToBeCompressed || bToBeEncrypted), "The stream is already encrypted!\n" );
+                        xSeek->seek ( bRawStream ? rInfo.pStream->GetMagicalHackPos() : 0 );
+                        ImplSetStoredData ( *pTempEntry, xStream );
+
+                        // TODO/LATER: Get rid of hacks related to switching of Flag Method and Size properties!
+                    }
+                    else if ( bToBeEncrypted )
+                    {
+                        // this is the correct original size
+                        pTempEntry->nSize = static_cast < sal_Int32 > ( xSeek->getLength() );
+                        nOwnStreamOrigSize = pTempEntry->nSize;
+                    }
+    
+                    xSeek->seek ( 0 );
+                }
+                else
+                {
+                    // Okay, we don't have an xSeekable stream. This is possibly bad.
+                    // check if it's one of our own streams, if it is then we know that
+                    // each time we ask for it we'll get a new stream that will be
+                    // at position zero...otherwise, assert and skip this stream...
+                    if ( rInfo.pStream->IsPackageMember() )
+                    {
+                        // if the password has been changed than the stream should not be package member any more
+                        if ( rInfo.pStream->IsEncrypted() && rInfo.pStream->IsToBeEncrypted() )
+                        {
+                            // Should be handled close to the raw stream handling
+                            bTransportOwnEncrStreamAsRaw = sal_True;
+                            pTempEntry->nMethod = STORED;
+
+                            // TODO/LATER: get rid of this situation
+                            // this size should be different from the one that will be stored in manifest.xml
+                            // it is used in storing algorithms and after storing the correct size will be set
+                            pTempEntry->nSize = pTempEntry->nCompressedSize;
+                        }
+                    }
+                    else
+                    {
+                        OSL_FAIL( "The package component requires that every stream either be FROM a package or it must support XSeekable!" );
+                        bSuccess = false;
+                        return bSuccess;
+                    }
+                }
+            }
+            catch ( Exception& )
+            {
+                OSL_FAIL( "The stream provided to the package component has problems!" );
+                bSuccess = false;
+                return bSuccess;
+            }
+
+            if ( bToBeEncrypted || bRawStream || bTransportOwnEncrStreamAsRaw )
+            {
+                if ( bToBeEncrypted && !bTransportOwnEncrStreamAsRaw )
+                {
+                    Sequence < sal_uInt8 > aSalt ( 16 ), aVector ( 8 );
+                    rtl_random_getBytes ( rRandomPool, aSalt.getArray(), 16 );
+                    rtl_random_getBytes ( rRandomPool, aVector.getArray(), 8 );
+                    sal_Int32 nIterationCount = 1024;
+
+                    if ( !rInfo.pStream->HasOwnKey() )
+                        rInfo.pStream->setKey ( rEncryptionKey );
+
+                    rInfo.pStream->setInitialisationVector ( aVector );
+                    rInfo.pStream->setSalt ( aSalt );
+                    rInfo.pStream->setIterationCount ( nIterationCount );
+                }
+
+                // last property is digest, which is inserted later if we didn't have
+                // a magic header
+                aPropSet.realloc(PKG_SIZE_ENCR_MNFST);
+
+                aPropSet[PKG_MNFST_INIVECTOR].Name = sInitialisationVectorProperty;
+                aPropSet[PKG_MNFST_INIVECTOR].Value <<= rInfo.pStream->getInitialisationVector();
+                aPropSet[PKG_MNFST_SALT].Name = sSaltProperty;
+                aPropSet[PKG_MNFST_SALT].Value <<= rInfo.pStream->getSalt();
+                aPropSet[PKG_MNFST_ITERATION].Name = sIterationCountProperty;
+                aPropSet[PKG_MNFST_ITERATION].Value <<= rInfo.pStream->getIterationCount ();
+
+                // Need to store the uncompressed size in the manifest
+                OSL_ENSURE( nOwnStreamOrigSize >= 0, "The stream size was not correctly initialized!\n" );
+                aPropSet[PKG_MNFST_UCOMPSIZE].Name = sSizeProperty;
+                aPropSet[PKG_MNFST_UCOMPSIZE].Value <<= nOwnStreamOrigSize;
+
+                if ( bRawStream || bTransportOwnEncrStreamAsRaw )
+                {
+                    aPropSet[PKG_MNFST_DIGEST].Name = sDigestProperty;
+                    aPropSet[PKG_MNFST_DIGEST].Value <<= rInfo.pStream->getDigest();
+                }
+            }
+        }
+
+        // If the entry is already stored in the zip file in the format we
+        // want for this write...copy it raw
+        if ( !bUseNonSeekableAccess
+          && ( bRawStream || bTransportOwnEncrStreamAsRaw
+            || ( rInfo.pStream->IsPackageMember() && !bToBeEncrypted
+              && ( ( rInfo.pStream->aEntry.nMethod == DEFLATED && bToBeCompressed )
+                || ( rInfo.pStream->aEntry.nMethod == STORED && !bToBeCompressed ) ) ) ) )
+        {
+            // If it's a PackageMember, then it's an unbuffered stream and we need
+            // to get a new version of it as we can't seek backwards.
+            if ( rInfo.pStream->IsPackageMember() )
+            {
+                xStream = rInfo.pStream->getRawData();
+                if ( !xStream.is() )
+                {
+                    // Make sure that we actually _got_ a new one !
+                    OSL_FAIL( "ZipPackageStream didn't have a stream associated with it, skipping!" );
+                    bSuccess = false;
+                    return bSuccess;
+                }
+            }
+
+            try
+            {
+                if ( bRawStream )
+                    xStream->skipBytes( rInfo.pStream->GetMagicalHackPos() );
+
+                rZipOut.putNextEntry ( *pTempEntry, rInfo.pStream->getEncryptionData(), sal_False );
+                // the entry is provided to the ZipOutputStream that will delete it
+                pAutoTempEntry.release();
+
+                Sequence < sal_Int8 > aSeq ( n_ConstBufferSize );
+                sal_Int32 nLength;
+
+                do
+                {
+                    nLength = xStream->readBytes( aSeq, n_ConstBufferSize );
+                    rZipOut.rawWrite(aSeq, 0, nLength);
+                }
+                while ( nLength == n_ConstBufferSize );
+
+                rZipOut.rawCloseEntry();
+            }
+            catch ( ZipException& )
+            {
+                OSL_FAIL( "Error writing ZipOutputStream" );
+                bSuccess = false;
+            }
+            catch ( IOException& )
+            {
+                OSL_FAIL( "Error writing ZipOutputStream" );
+                bSuccess = false;
+            }
+        }
+        else
+        {
+            // This stream is defenitly not a raw stream
+
+            // If nonseekable access is used the stream should be at the beginning and
+            // is useless after the storing. Thus if the storing fails the package should
+            // be thrown away ( as actually it is done currently )!
+            // To allow to reuse the package after the error, the optimization must be removed!
+
+            // If it's a PackageMember, then our previous reference held a 'raw' stream
+            // so we need to re-get it, unencrypted, uncompressed and positioned at the
+            // beginning of the stream
+            if ( rInfo.pStream->IsPackageMember() )
+            {
+                xStream = rInfo.pStream->getInputStream();
+                if ( !xStream.is() )
+                {
+                    // Make sure that we actually _got_ a new one !
+                    OSL_FAIL( "ZipPackageStream didn't have a stream associated with it, skipping!" );
+                    bSuccess = false;
+                    return bSuccess;
+                }
+            }
+
+            if ( bToBeCompressed )
+            {
+                pTempEntry->nMethod = DEFLATED;
+                pTempEntry->nCrc = pTempEntry->nCompressedSize = pTempEntry->nSize = -1;
+            }
+
+            try
+            {
+                rZipOut.putNextEntry ( *pTempEntry, rInfo.pStream->getEncryptionData(), bToBeEncrypted);
+                // the entry is provided to the ZipOutputStream that will delete it
+                pAutoTempEntry.release();
+
+                sal_Int32 nLength;
+                Sequence < sal_Int8 > aSeq (n_ConstBufferSize);
+                do
+                {
+                    nLength = xStream->readBytes(aSeq, n_ConstBufferSize);
+                    rZipOut.write(aSeq, 0, nLength);
+                }
+                while ( nLength == n_ConstBufferSize );
+
+                rZipOut.closeEntry();
+            }
+            catch ( ZipException& )
+            {
+                OSL_FAIL( "Error writing ZipOutputStream" );
+                bSuccess = false;
+            }
+            catch ( IOException& )
+            {
+                OSL_FAIL( "Error writing ZipOutputStream" );
+                bSuccess = false;
+            }
+
+            if ( bToBeEncrypted )
+            {
+                aPropSet[PKG_MNFST_DIGEST].Name = sDigestProperty;
+                aPropSet[PKG_MNFST_DIGEST].Value <<= rInfo.pStream->getDigest();
+                rInfo.pStream->SetIsEncrypted ( sal_True );
+            }
+        }
+
+        if( bSuccess )
+        {
+            if ( !rInfo.pStream->IsPackageMember() )
+            {
+                rInfo.pStream->CloseOwnStreamIfAny();
+                rInfo.pStream->SetPackageMember ( sal_True );
+            }
+
+            if ( bRawStream )
+            {
+                // the raw stream was integrated and now behaves
+                // as usual encrypted stream
+                rInfo.pStream->SetToBeEncrypted( sal_True );
+            }
+
+            // Remove hacky bit from entry flags
+            if ( pTempEntry->nFlag & ( 1 << 4 ) )
+            {
+                pTempEntry->nFlag &= ~( 1 << 4 );
+                pTempEntry->nMethod = STORED;
+            }
+
+            // Then copy it back afterwards...
+            ZipPackageFolder::copyZipEntry ( rInfo.pStream->aEntry, *pTempEntry );
+
+            // TODO/LATER: get rid of this hack ( the encrypted stream size property is changed during saving )
+            if ( rInfo.pStream->IsEncrypted() )
+                rInfo.pStream->setSize( nOwnStreamOrigSize );
+
+            rInfo.pStream->aEntry.nOffset *= -1;
+        }
+    }
+
+    // folder can have a mediatype only in package format
+    if ( aPropSet.getLength()
+      && ( m_nFormat == embed::StorageFormats::PACKAGE || ( m_nFormat == embed::StorageFormats::OFOPXML && !rInfo.bFolder ) ) )
+        rManList.push_back( aPropSet );
+
+    return bSuccess;
+}
+
+void ZipPackageFolder::saveContents(OUString &rPath, std::vector < Sequence < PropertyValue > > &rManList, ZipOutputStream & rZipOut, Sequence < sal_Int8 > &rEncryptionKey, rtlRandomPool &rRandomPool)
+    throw(RuntimeException)
+{
+    bool bWritingFailed = false;
 
     if ( maContents.begin() == maContents.end() && rPath.getLength() && m_nFormat != embed::StorageFormats::OFOPXML )
     {
@@ -341,363 +687,38 @@ void ZipPackageFolder::saveContents(OUString &rPath, std::vector < Sequence < Pr
         }
         catch ( ZipException& )
         {
-            OSL_ENSURE( 0, "Error writing ZipOutputStream" );
-            bWritingFailed = sal_True;
+            OSL_FAIL( "Error writing ZipOutputStream" );
+            bWritingFailed = true;
         }
         catch ( IOException& )
         {
-            OSL_ENSURE( 0, "Error writing ZipOutputStream" );
-            bWritingFailed = sal_True;
+            OSL_FAIL( "Error writing ZipOutputStream" );
+            bWritingFailed = true;
+        }
+    }
+
+    bool bMimeTypeStreamStored = false;
+    ::rtl::OUString aMimeTypeStreamName( RTL_CONSTASCII_USTRINGPARAM( "mimetype" ) );
+    if ( m_nFormat == embed::StorageFormats::ZIP && !rPath.getLength() )
+    {
+        // let the "mimtype" stream in root folder be stored as the first stream if it is zip format
+        ContentHash::iterator aIter = maContents.find ( aMimeTypeStreamName );
+        if ( aIter != maContents.end() && !(*aIter).second->bFolder )
+        {
+            bMimeTypeStreamStored = true;
+            bWritingFailed = !saveChild( (*aIter).first, *(*aIter).second, rPath, rManList, rZipOut, rEncryptionKey, rRandomPool );
         }
     }
 
     for ( ContentHash::const_iterator aCI = maContents.begin(), aEnd = maContents.end();
-          aCI != aEnd; 
+          aCI != aEnd;
           aCI++)
-    { 
+    {
         const OUString &rShortName = (*aCI).first;
         const ContentInfo &rInfo = *(*aCI).second;
 
-        Sequence < PropertyValue > aPropSet (PKG_SIZE_NOENCR_MNFST);
-        PropertyValue *pValue = aPropSet.getArray();
-
-        if ( rInfo.bFolder )
-            pFolder = rInfo.pFolder;
-        else
-            pStream = rInfo.pStream;
-        
-        if ( rInfo.bFolder )
-        {
-            OUString sTempName = rPath + rShortName + OUString( RTL_CONSTASCII_USTRINGPARAM ( "/" ) );
-
-            pValue[PKG_MNFST_MEDIATYPE].Name = sMediaTypeProperty;
-            pValue[PKG_MNFST_MEDIATYPE].Value <<= pFolder->GetMediaType();
-            pValue[PKG_MNFST_VERSION].Name = sVersionProperty;
-            pValue[PKG_MNFST_VERSION].Value <<= pFolder->GetVersion();
-            pValue[PKG_MNFST_FULLPATH].Name = sFullPathProperty;
-            pValue[PKG_MNFST_FULLPATH].Value <<= sTempName;
-            
-            pFolder->saveContents( sTempName, rManList, rZipOut, rEncryptionKey, rRandomPool);
-        }
-        else
-        {
-            // if pTempEntry is necessary, it will be released and passed to the ZipOutputStream
-            // and be deleted in the ZipOutputStream destructor 
-            auto_ptr < ZipEntry > pAutoTempEntry ( new ZipEntry );
-            ZipEntry* pTempEntry = pAutoTempEntry.get();
-
-            // In case the entry we are reading is also the entry we are writing, we will
-            // store the ZipEntry data in pTempEntry
-
-            ZipPackageFolder::copyZipEntry ( *pTempEntry, pStream->aEntry );
-            pTempEntry->sPath = rPath + rShortName;
-            pTempEntry->nPathLen = (sal_Int16)( ::rtl::OUStringToOString( pTempEntry->sPath, RTL_TEXTENCODING_UTF8 ).getLength() );
-
-            sal_Bool bToBeEncrypted = pStream->IsToBeEncrypted() && (bHaveEncryptionKey || pStream->HasOwnKey());
-            sal_Bool bToBeCompressed = bToBeEncrypted ? sal_True : pStream->IsToBeCompressed();
-
-            pValue[PKG_MNFST_MEDIATYPE].Name = sMediaTypeProperty;
-            pValue[PKG_MNFST_MEDIATYPE].Value <<= pStream->GetMediaType( );
-            pValue[PKG_MNFST_VERSION].Name = sVersionProperty;
-            pValue[PKG_MNFST_VERSION].Value <<= ::rtl::OUString(); // no version is stored for streams currently
-            pValue[PKG_MNFST_FULLPATH].Name = sFullPathProperty;
-            pValue[PKG_MNFST_FULLPATH].Value <<= pTempEntry->sPath;
-
-
-            OSL_ENSURE( pStream->GetStreamMode() != PACKAGE_STREAM_NOTSET, "Unacceptable ZipPackageStream mode!" );
-
-            sal_Bool bRawStream = sal_False;
-            if ( pStream->GetStreamMode() == PACKAGE_STREAM_DETECT )
-                bRawStream = pStream->ParsePackageRawStream();
-            else if ( pStream->GetStreamMode() == PACKAGE_STREAM_RAW )
-                bRawStream = sal_True;
-
-            sal_Bool bTransportOwnEncrStreamAsRaw = sal_False;
-            // During the storing the original size of the stream can be changed
-            // TODO/LATER: get rid of this hack
-            sal_Int32 nOwnStreamOrigSize = bRawStream ? pStream->GetMagicalHackSize() : pStream->getSize();
-
-            sal_Bool bUseNonSeekableAccess = sal_False;
-            Reference < XInputStream > xStream;
-            if ( !pStream->IsPackageMember() && !bRawStream && !bToBeEncrypted && bToBeCompressed )
-            {
-                // the stream is not a package member, not a raw stream,
-                // it should not be encrypted and it should be compressed,
-                // in this case nonseekable access can be used
-
-                xStream = pStream->GetOwnStreamNoWrap();
-                Reference < XSeekable > xSeek ( xStream, UNO_QUERY );
-
-                bUseNonSeekableAccess = ( xStream.is() && !xSeek.is() );
-            }
-
-            if ( !bUseNonSeekableAccess )
-            {
-                xStream = pStream->getRawData();
-
-                if ( !xStream.is() )
-                {
-                    OSL_ENSURE( 0, "ZipPackageStream didn't have a stream associated with it, skipping!" );
-                    bWritingFailed = sal_True;
-                    continue;
-                }
-
-                Reference < XSeekable > xSeek ( xStream, UNO_QUERY );
-                try
-                {
-                    if ( xSeek.is() )
-                    {
-                        // If the stream is a raw one, then we should be positioned
-                        // at the beginning of the actual data
-                        if ( !bToBeCompressed || bRawStream )
-                        {
-                            // The raw stream can neither be encrypted nor connected
-                            OSL_ENSURE( !bRawStream || !bToBeCompressed && !bToBeEncrypted, "The stream is already encrypted!\n" );
-                            xSeek->seek ( bRawStream ? pStream->GetMagicalHackPos() : 0 );
-                            ImplSetStoredData ( *pTempEntry, xStream );
-    
-                            // TODO/LATER: Get rid of hacks related to switching of Flag Method and Size properties!
-                        }
-                        else if ( bToBeEncrypted )
-                        {
-                            // this is the correct original size
-                            pTempEntry->nSize = static_cast < sal_Int32 > ( xSeek->getLength() );
-                            nOwnStreamOrigSize = pTempEntry->nSize;
-                        }
-        
-                        xSeek->seek ( 0 );
-                    }
-                    else
-                    {
-                        // Okay, we don't have an xSeekable stream. This is possibly bad.
-                        // check if it's one of our own streams, if it is then we know that
-                        // each time we ask for it we'll get a new stream that will be
-                        // at position zero...otherwise, assert and skip this stream...
-                        if ( pStream->IsPackageMember() )
-                        {
-                            // if the password has been changed than the stream should not be package member any more
-                            if ( pStream->IsEncrypted() && pStream->IsToBeEncrypted() )
-                            {
-                                // Should be handled close to the raw stream handling
-                                bTransportOwnEncrStreamAsRaw = sal_True;
-                                pTempEntry->nMethod = STORED;
-    
-                                // TODO/LATER: get rid of this situation
-                                // this size should be different from the one that will be stored in manifest.xml
-                                // it is used in storing algorithms and after storing the correct size will be set
-                                pTempEntry->nSize = pTempEntry->nCompressedSize;
-                            }
-                        }
-                        else
-                        {
-                            OSL_ENSURE( 0, "The package component requires that every stream either be FROM a package or it must support XSeekable!" );
-                            continue;
-                        }
-                    }
-                }
-                catch ( Exception& )
-                {
-                    OSL_ENSURE( 0, "The stream provided to the package component has problems!" );
-                    bWritingFailed = sal_True;
-                    continue;
-                }
-    
-                if ( bToBeEncrypted || bRawStream || bTransportOwnEncrStreamAsRaw )
-                {
-                    if ( bToBeEncrypted && !bTransportOwnEncrStreamAsRaw )
-                    {
-                        Sequence < sal_uInt8 > aSalt ( 16 ), aVector ( 8 ); 
-                        rtl_random_getBytes ( rRandomPool, aSalt.getArray(), 16 );
-                        rtl_random_getBytes ( rRandomPool, aVector.getArray(), 8 );
-                        sal_Int32 nIterationCount = 1024;
-            
-                        if ( !pStream->HasOwnKey() )
-                            pStream->setKey ( rEncryptionKey );
-
-                        pStream->setInitialisationVector ( aVector );
-                        pStream->setSalt ( aSalt );
-                        pStream->setIterationCount ( nIterationCount );
-                    }
-    
-                    // last property is digest, which is inserted later if we didn't have
-                    // a magic header
-                    aPropSet.realloc(PKG_SIZE_ENCR_MNFST);
-
-                    pValue = aPropSet.getArray();
-                    pValue[PKG_MNFST_INIVECTOR].Name = sInitialisationVectorProperty;
-                    pValue[PKG_MNFST_INIVECTOR].Value <<= pStream->getInitialisationVector();
-                    pValue[PKG_MNFST_SALT].Name = sSaltProperty;
-                    pValue[PKG_MNFST_SALT].Value <<= pStream->getSalt();
-                    pValue[PKG_MNFST_ITERATION].Name = sIterationCountProperty;
-                    pValue[PKG_MNFST_ITERATION].Value <<= pStream->getIterationCount ();
-                    
-                    // Need to store the uncompressed size in the manifest
-                    OSL_ENSURE( nOwnStreamOrigSize >= 0, "The stream size was not correctly initialized!\n" );
-                    pValue[PKG_MNFST_UCOMPSIZE].Name = sSizeProperty;
-                    pValue[PKG_MNFST_UCOMPSIZE].Value <<= nOwnStreamOrigSize;
-    
-                    if ( bRawStream || bTransportOwnEncrStreamAsRaw )
-                    {
-                        pValue[PKG_MNFST_DIGEST].Name = sDigestProperty;
-                        pValue[PKG_MNFST_DIGEST].Value <<= pStream->getDigest();
-                    }
-                }
-            }
-
-            // If the entry is already stored in the zip file in the format we
-            // want for this write...copy it raw
-            if ( !bUseNonSeekableAccess
-              && ( bRawStream || bTransportOwnEncrStreamAsRaw
-                || ( pStream->IsPackageMember() && !bToBeEncrypted
-                  && ( ( pStream->aEntry.nMethod == DEFLATED && bToBeCompressed )
-                    || ( pStream->aEntry.nMethod == STORED && !bToBeCompressed ) ) ) ) )
-            {
-                // If it's a PackageMember, then it's an unbuffered stream and we need
-                // to get a new version of it as we can't seek backwards.
-                if ( pStream->IsPackageMember() )
-                {	
-                    xStream = pStream->getRawData();
-                    if ( !xStream.is() )
-                    {
-                        // Make sure that we actually _got_ a new one !
-                        OSL_ENSURE( 0, "ZipPackageStream didn't have a stream associated with it, skipping!" );
-                        continue;
-                    }
-                }
-
-                try
-                {
-                    if ( bRawStream )
-                        xStream->skipBytes( pStream->GetMagicalHackPos() );
-
-                    rZipOut.putNextEntry ( *pTempEntry, pStream->getEncryptionData(), sal_False );
-                    // the entry is provided to the ZipOutputStream that will delete it
-                    pAutoTempEntry.release();
-
-                    Sequence < sal_Int8 > aSeq ( n_ConstBufferSize );
-                    sal_Int32 nLength;
-
-                    do
-                    {
-                        nLength = xStream->readBytes( aSeq, n_ConstBufferSize );
-                        rZipOut.rawWrite(aSeq, 0, nLength);
-                    }
-                    while ( nLength == n_ConstBufferSize );
-
-                    rZipOut.rawCloseEntry();
-                }
-                catch ( ZipException& )
-                {
-                    OSL_ENSURE( 0, "Error writing ZipOutputStream" );
-                    bWritingFailed = sal_True;
-                }
-                catch ( IOException& )
-                {
-                    OSL_ENSURE( 0, "Error writing ZipOutputStream" );
-                    bWritingFailed = sal_True;
-                }
-            }
-            else
-            {
-                // This stream is defenitly not a raw stream
-            
-                // If nonseekable access is used the stream should be at the beginning and
-                // is useless after the storing. Thus if the storing fails the package should
-                // be thrown away ( as actually it is done currently )!
-                // To allow to reuse the package after the error, the optimization must be removed!
-            
-                // If it's a PackageMember, then our previous reference held a 'raw' stream
-                // so we need to re-get it, unencrypted, uncompressed and positioned at the
-                // beginning of the stream
-                if ( pStream->IsPackageMember() )
-                {	
-                    xStream = pStream->getInputStream();
-                    if ( !xStream.is() )
-                    {
-                        // Make sure that we actually _got_ a new one !
-                        OSL_ENSURE( 0, "ZipPackageStream didn't have a stream associated with it, skipping!" );
-                        continue;
-                    }
-                }
-
-                if ( bToBeCompressed )
-                {
-                    pTempEntry->nMethod = DEFLATED;
-                    pTempEntry->nCrc = pTempEntry->nCompressedSize = pTempEntry->nSize = -1;
-                }
-
-                try
-                {
-                    rZipOut.putNextEntry ( *pTempEntry, pStream->getEncryptionData(), bToBeEncrypted);
-                    // the entry is provided to the ZipOutputStream that will delete it
-                    pAutoTempEntry.release();
-
-                    sal_Int32 nLength;
-                    Sequence < sal_Int8 > aSeq (n_ConstBufferSize);
-                    do
-                    {
-                        nLength = xStream->readBytes(aSeq, n_ConstBufferSize);
-                        rZipOut.write(aSeq, 0, nLength);
-                    }
-                    while ( nLength == n_ConstBufferSize );
-
-                    rZipOut.closeEntry();
-                }
-                catch ( ZipException& )
-                {
-                    OSL_ENSURE( 0, "Error writing ZipOutputStream" );
-                    bWritingFailed = sal_True;
-                }
-                catch ( IOException& )
-                {
-                    OSL_ENSURE( 0, "Error writing ZipOutputStream" );
-                    bWritingFailed = sal_True;
-                }
-
-                if ( bToBeEncrypted )
-                {
-                    pValue[PKG_MNFST_DIGEST].Name = sDigestProperty;
-                    pValue[PKG_MNFST_DIGEST].Value <<= pStream->getDigest();
-                    pStream->SetIsEncrypted ( sal_True );
-                }
-            }
-
-            if( !bWritingFailed )
-            {
-                if ( !pStream->IsPackageMember() )
-                {
-                    pStream->CloseOwnStreamIfAny();
-                    pStream->SetPackageMember ( sal_True );
-                }
-
-                if ( bRawStream )
-                {
-                    // the raw stream was integrated and now behaves
-                    // as usual encrypted stream
-                    pStream->SetToBeEncrypted( sal_True );
-                }
-    
-                // Remove hacky bit from entry flags
-                if ( pTempEntry->nFlag & ( 1 << 4 ) )
-                {
-                    pTempEntry->nFlag &= ~( 1 << 4 );
-                    pTempEntry->nMethod = STORED;
-                }
-
-                // Then copy it back afterwards...
-                ZipPackageFolder::copyZipEntry ( pStream->aEntry, *pTempEntry );
-
-                // TODO/LATER: get rid of this hack ( the encrypted stream size property is changed during saving )
-                if ( pStream->IsEncrypted() )
-                    pStream->setSize( nOwnStreamOrigSize );
-
-                pStream->aEntry.nOffset *= -1;
-            }
-        }
-
-        // folder can have a mediatype only in package format
-        if ( m_nFormat == embed::StorageFormats::PACKAGE || ( m_nFormat == embed::StorageFormats::OFOPXML && !rInfo.bFolder ) )
-            rManList.push_back( aPropSet );
+        if ( !bMimeTypeStreamStored || !rShortName.equals( aMimeTypeStreamName ) )
+            bWritingFailed = !saveChild( rShortName, rInfo, rPath, rManList, rZipOut, rEncryptionKey, rRandomPool );
     }
     
     if( bWritingFailed )
