@@ -144,11 +144,11 @@ int SAL_CALL main( int argc, char **argv )
         Reference< XMultiComponentFactory > xManager = NULL ;
         Reference< XComponentContext > xContext = NULL ;
 
-        xManager = serviceManager( xContext , OUString::createFromAscii( "local" ), OUString::createFromAscii( argv[6] ) ) ;
+        xManager = serviceManager( xContext , OUString(RTL_CONSTASCII_USTRINGPARAM("local")), OUString::createFromAscii( argv[6] ) ) ;
 
         //Create encryption template
         Reference< XInterface > tplElement =
-            xManager->createInstanceWithContext( OUString::createFromAscii( "com.sun.star.xml.security.bridge.xmlsec.XMLElementWrapper_XmlSecImpl" ) , xContext ) ;
+            xManager->createInstanceWithContext( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.xml.security.bridge.xmlsec.XMLElementWrapper_XmlSecImpl")) , xContext ) ;
         OSL_ENSURE( tplElement.is() ,
             "Encryptor - "
             "Cannot get service instance of \"xsec.XMLElementWrapper\"" ) ;
@@ -172,7 +172,7 @@ int SAL_CALL main( int argc, char **argv )
 
         //Create encryption target element
         Reference< XInterface > tarElement =
-            xManager->createInstanceWithContext( OUString::createFromAscii( "com.sun.star.xml.security.bridge.xmlsec.XMLElementWrapper_XmlSecImpl" ) , xContext ) ;
+            xManager->createInstanceWithContext( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.xml.security.bridge.xmlsec.XMLElementWrapper_XmlSecImpl")) , xContext ) ;
         OSL_ENSURE( tarElement.is() ,
             "Encryptor - "
             "Cannot get service instance of \"xsec.XMLElementWrapper\"" ) ;
@@ -197,7 +197,7 @@ int SAL_CALL main( int argc, char **argv )
 
         //Build XML Encryption template
         Reference< XInterface > enctpl =
-            xManager->createInstanceWithContext( OUString::createFromAscii("com.sun.star.xml.crypto.XMLEncryptionTemplate"), xContext ) ;
+            xManager->createInstanceWithContext( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.xml.crypto.XMLEncryptionTemplate")), xContext ) ;
         OSL_ENSURE( enctpl.is() ,
             "Encryptor - "
             "Cannot get service instance of \"xsec.XMLEncryptionTemplate\"" ) ;
@@ -214,7 +214,7 @@ int SAL_CALL main( int argc, char **argv )
         //Create security environment
         //Build Security Environment
         Reference< XInterface > xsecenv =
-            xManager->createInstanceWithContext( OUString::createFromAscii("com.sun.star.xml.security.bridge.xmlsec.SecurityEnvironment_NssImpl"), xContext ) ;
+            xManager->createInstanceWithContext( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.xml.security.bridge.xmlsec.SecurityEnvironment_NssImpl")), xContext ) ;
         OSL_ENSURE( xsecenv.is() ,
             "Encryptor - "
             "Cannot get service instance of \"xsec.SecurityEnvironment\"" ) ;
@@ -242,7 +242,7 @@ int SAL_CALL main( int argc, char **argv )
 
         //Build XML Security Context
         Reference< XInterface > xmlsecctx =
-            xManager->createInstanceWithContext( OUString::createFromAscii("com.sun.star.xml.security.bridge.xmlsec.XMLSecurityContext_NssImpl"), xContext ) ;
+            xManager->createInstanceWithContext( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.xml.security.bridge.xmlsec.XMLSecurityContext_NssImpl")), xContext ) ;
         OSL_ENSURE( xmlsecctx.is() ,
             "Encryptor - "
             "Cannot get service instance of \"xsec.XMLSecurityContext\"" ) ;
@@ -256,7 +256,7 @@ int SAL_CALL main( int argc, char **argv )
 
         //Get encrypter
         Reference< XInterface > xmlencrypter =
-            xManager->createInstanceWithContext( OUString::createFromAscii("com.sun.star.xml.security.bridge.xmlsec.XMLEncryption_NssImpl"), xContext ) ;
+            xManager->createInstanceWithContext( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.xml.security.bridge.xmlsec.XMLEncryption_NssImpl")), xContext ) ;
         OSL_ENSURE( xmlencrypter.is() ,
             "Encryptor - "
             "Cannot get service instance of \"xsec.XMLEncryption\"" ) ;
